getCardState method
Loads the scheduling state for a card by cardId, or returns null if not found.
Implementation
@override
Future<SRSCardState?> getCardState(String cardId) async => _store[cardId];
Loads the scheduling state for a card by cardId, or returns null if not found.
@override
Future<SRSCardState?> getCardState(String cardId) async => _store[cardId];