seed method
Pre-seeds the store with a list of card states.
Implementation
void seed(List<SRSCardState> states) {
for (final state in states) {
_store[state.cardId] = state;
}
}
Pre-seeds the store with a list of card states.
void seed(List<SRSCardState> states) {
for (final state in states) {
_store[state.cardId] = state;
}
}