InMemoryCardStateStore class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
store
→ Map<
String, SRSCardState> -
no setter
Methods
-
clear(
) → void -
deleteCardState(
String cardId) → Future< void> -
override
-
getCardsByIds(
List< String> cardIds) → Future<List< SRSCardState> > -
override
-
getCardState(
String cardId) → Future< SRSCardState?> -
override
-
getDueCards(
DateTime now) → Future< List< SRSCardState> > -
override
-
getNewCards(
int limit) → Future< List< SRSCardState> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveCardState(
SRSCardState state) → Future< void> -
override
-
saveCardStates(
List< SRSCardState> states) → Future<void> -
override
-
seed(
List< SRSCardState> states) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited